==> apache-doris-2.1.11-rc01-src.tar.gz: apache-doris-2.1.11-rc01-src/fe/fe-common/src/test/java/org/apache/doris/common/io/DiskUtilsTest.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.apache.doris.common.io;

import org.junit.Assert;
import org.junit.Test;

public class DiskUtilsTest {
    @Test
    public void testSiseFormat() {
        long [] keys = new long[]{
            1L,
            1L * 1024,
            1L * 1024 * 1024,
            1L * 1024 * 1024 * 1024,
            1L * 1024 * 1024 * 1024 * 1024,
            1L * 1024 * 1024 * 1024 * 1024 * 1024,
            1L * 1024 * 1024 * 1024 * 1024 * 1024 * 1024,
        };

        String[] values = new String[]{
            "1",
            "1K",
            "1M",
            "1G",
            "1T",
            "1P",
            "1024P",
        };

        for (int i = 0; i < values.length; i++) {
            Assert.assertEquals(values[i], DiskUtils.sizeFormat(keys[i]));
        }
    }
}

==> apache-doris-3.0.8-rc01-src.tar.gz: apache-doris-3.0.8-rc01-src/fe/fe-common/src/test/java/org/apache/doris/common/io/DiskUtilsTest.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.apache.doris.common.io;

import org.junit.Assert;
import org.junit.Test;

public class DiskUtilsTest {
    @Test
    public void testSiseFormat() {
        long[] keys = new long[] {
                1L,
                1L * 1024,
                1L * 1024 * 1024,
                1L * 1024 * 1024 * 1024,
                1L * 1024 * 1024 * 1024 * 1024,
                1L * 1024 * 1024 * 1024 * 1024 * 1024,
                1L * 1024 * 1024 * 1024 * 1024 * 1024 * 1024,
        };

        String[] values = new String[] {
                "1",
                "1K",
                "1M",
                "1G",
                "1T",
                "1P",
                "1024P",
        };

        for (int i = 0; i < values.length; i++) {
            Assert.assertEquals(values[i], DiskUtils.sizeFormat(keys[i]));
        }
    }

    @Test
    public void testDf() {
        DiskUtils.Df d = DiskUtils.df("/proc");
        Assert.assertTrue(d.fileSystem.length() != 0);
    }
}
